@@ -1,7 +1,7 @@
 // qjackctlSessionForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -93,7 +93,7 @@ class qjackctlSessionInfraClientItemDelegate : public QItemDelegate
 public:
 
 	// Constructor.
-	qjackctlSessionInfraClientItemDelegate(QObject *pParent = NULL);
+	qjackctlSessionInfraClientItemDelegate(QObject *pParent = nullptr);
 
 protected:
 
