@@ -24,6 +24,8 @@
 
 #include "qjackctlMainForm.h"
 
+#include "qjackctlPaletteForm.h"
+
 #include "qjackctlSetup.h"
 
 #include <QValidator>
@@ -37,6 +39,8 @@
 
 #include <QButtonGroup>
 
+#include <QStyleFactory>
+
 #ifdef CONFIG_SYSTEM_TRAY
 #include <QSystemTrayIcon>
 #endif
@@ -60,6 +64,10 @@
 #endif
 
 
+// Default (empty/blank) name.
+static const char *g_pszDefName = QT_TRANSLATE_NOOP("qjackctlSetupForm", "(default)");
+
+
 //----------------------------------------------------------------------------
 // qjackctlSetupForm -- UI wrapper form.
 
@@ -330,6 +338,15 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.DisplayBlinkCheckBox,
 		SIGNAL(toggled(bool)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.CustomColorThemeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.CustomColorThemeToolButton,
+		SIGNAL(clicked()),
+		SLOT(editCustomColorThemes()));
+	QObject::connect(m_ui.CustomStyleThemeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.DisplayFont1PushButton,
 		SIGNAL(clicked()),
 		SLOT(chooseDisplayFont1()));
@@ -623,6 +640,10 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	else
 		m_ui.BaseFontSizeComboBox->setCurrentIndex(0);
 
+	// Custom display options...
+	resetCustomColorThemes(m_pSetup->sCustomColorTheme);
+	resetCustomStyleThemes(m_pSetup->sCustomStyleTheme);
+
 #ifdef CONFIG_SYSTEM_TRAY
 	const bool bSystemTray = QSystemTrayIcon::isSystemTrayAvailable();
 #else
@@ -661,6 +682,8 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	// Load preset list...
 	resetPresets();
 	updateCurrentPreset();
+	// Make sure initial preset is not dirty...
+	m_iDirtyPreset = 0;
 
 	// We're clean now.
 	--m_iDirtySetup;
@@ -1479,6 +1502,76 @@ void qjackctlSetupForm::chooseConnectionsFont (void)
 }
 
 
+// Custom color palette theme manager.
+void qjackctlSetupForm::editCustomColorThemes (void)
+{
+	qjackctlPaletteForm form(this);
+	form.setSettings(&m_pSetup->settings());
+
+	QString sCustomColorTheme;
+	int iDirtyCustomColorTheme = 0;
+
+	const int iCustomColorTheme
+		= m_ui.CustomColorThemeComboBox->currentIndex();
+	if (iCustomColorTheme > 0) {
+		sCustomColorTheme = m_ui.CustomColorThemeComboBox->itemText(
+			iCustomColorTheme);
+		form.setPaletteName(sCustomColorTheme);
+	}
+
+	if (form.exec() == QDialog::Accepted) {
+		sCustomColorTheme = form.paletteName();
+		++iDirtyCustomColorTheme;
+	}
+
+	if (iDirtyCustomColorTheme > 0 || form.isDirty()) {
+		resetCustomColorThemes(sCustomColorTheme);
+		optionsChanged();
+	}
+}
+
+
+// Custom color palette themes settler.
+void qjackctlSetupForm::resetCustomColorThemes (
+	const QString& sCustomColorTheme )
+{
+	m_ui.CustomColorThemeComboBox->clear();
+	m_ui.CustomColorThemeComboBox->addItem(
+		tr(g_pszDefName));
+	m_ui.CustomColorThemeComboBox->addItems(
+		qjackctlPaletteForm::namedPaletteList(&m_pSetup->settings()));
+
+	int iCustomColorTheme = 0;
+	if (!sCustomColorTheme.isEmpty()) {
+		iCustomColorTheme = m_ui.CustomColorThemeComboBox->findText(
+			sCustomColorTheme);
+		if (iCustomColorTheme < 0)
+			iCustomColorTheme = 0;
+	}
+	m_ui.CustomColorThemeComboBox->setCurrentIndex(iCustomColorTheme);
+}
+
+
+// Custom widget style themes settler.
+void qjackctlSetupForm::resetCustomStyleThemes (
+	const QString& sCustomStyleTheme )
+{
+	m_ui.CustomStyleThemeComboBox->clear();
+	m_ui.CustomStyleThemeComboBox->addItem(
+		tr(g_pszDefName));
+	m_ui.CustomStyleThemeComboBox->addItems(QStyleFactory::keys());
+
+	int iCustomStyleTheme = 0;
+	if (!sCustomStyleTheme.isEmpty()) {
+		iCustomStyleTheme = m_ui.CustomStyleThemeComboBox->findText(
+			sCustomStyleTheme);
+		if (iCustomStyleTheme < 0)
+			iCustomStyleTheme = 0;
+	}
+	m_ui.CustomStyleThemeComboBox->setCurrentIndex(iCustomStyleTheme);
+}
+
+
 // Brag about any buffer-size (frames/period) changes...
 void qjackctlSetupForm::buffSizeChanged (void)
 {
@@ -1626,6 +1719,45 @@ void qjackctlSetupForm::apply (void)
 		m_pSetup->bTextLabels              = !m_ui.TextLabelsCheckBox->isChecked();
 		m_pSetup->bGraphButton             = m_ui.GraphButtonCheckBox->isChecked();
 		m_pSetup->iBaseFontSize            = m_ui.BaseFontSizeComboBox->currentText().toInt();
+		// Custom color/style theme options...
+		const QString sOldCustomStyleTheme = m_pSetup->sCustomStyleTheme;
+		if (m_ui.CustomStyleThemeComboBox->currentIndex() > 0)
+			m_pSetup->sCustomStyleTheme = m_ui.CustomStyleThemeComboBox->currentText();
+		else
+			m_pSetup->sCustomStyleTheme.clear();
+		const QString sOldCustomColorTheme = m_pSetup->sCustomColorTheme;
+		if (m_ui.CustomColorThemeComboBox->currentIndex() > 0)
+			m_pSetup->sCustomColorTheme = m_ui.CustomColorThemeComboBox->currentText();
+		else
+			m_pSetup->sCustomColorTheme.clear();
+		// Check whether restart is needed or whether
+		// custom options maybe set up immediately...
+		int iNeedRestart = 0;
+		if (m_pSetup->sCustomStyleTheme != sOldCustomStyleTheme) {
+			if (m_pSetup->sCustomStyleTheme.isEmpty()) {
+				++iNeedRestart;
+			} else {
+				QApplication::setStyle(
+					QStyleFactory::create(m_pSetup->sCustomStyleTheme));
+			}
+		}
+		if (m_pSetup->sCustomColorTheme != sOldCustomColorTheme) {
+			if (m_pSetup->sCustomColorTheme.isEmpty()) {
+				++iNeedRestart;
+			} else {
+				QPalette pal;
+				if (qjackctlPaletteForm::namedPalette(
+						&m_pSetup->settings(), m_pSetup->sCustomColorTheme, pal))
+					QApplication::setPalette(pal);
+			}
+		}
+		// Show restart message if needed...
+		if (iNeedRestart > 0) {
+			QMessageBox::information(this,
+				tr("Information"),
+				tr("Some settings may be only effective\n"
+				"next time you start this application."));
+		}
 		// Check wheather something immediate has changed.
 		if (( bOldMessagesLog && !m_pSetup->bMessagesLog) ||
 			(!bOldMessagesLog &&  m_pSetup->bMessagesLog) ||
@@ -1807,7 +1939,7 @@ void qjackctlSetupForm::showEvent ( QShowEvent *pShowEvent )
 {
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->stabilizeForm();
+		pMainForm->stabilizeFormEx();
 
 	stabilizeForm();
 
@@ -1821,17 +1953,7 @@ void qjackctlSetupForm::hideEvent ( QHideEvent *pHideEvent )
 
 	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 	if (pMainForm)
-		pMainForm->stabilizeForm();
-}
-
-// Just about to notify main-window that we're closing.
-void qjackctlSetupForm::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
-{
-	QDialog::hide();
-
-	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
-	if (pMainForm)
-		pMainForm->stabilizeForm();
+		pMainForm->stabilizeFormEx();
 }
 
 
